@@ -14,7 +14,7 @@ PATH = "/users/{user_uuid}/institutions/{institution_id}/balances"
 
 class BalanceRecord(BaseModel):
     description: Optional[str]
-    balance: int
+    balance: float
     ts: int
     currency: Optional[str]
     labels: Set[str]
@@ -86,6 +86,7 @@ class BaseBalancesResource(ABC):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[BalanceRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -94,9 +95,10 @@ class BaseBalancesResource(ABC):
             utc_endtime=utc_endtime,
             labels=labels,
             account_types=account_types,
+            page=page or 1,
         )
         max_pages = response.meta.max_pages
-        if max_pages > 1:
+        if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
                     user_uuid=user_uuid,
@@ -132,6 +134,7 @@ class AsyncBalancesResource(BaseBalancesResource):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[BalanceRecord]:
         return await self._get(
             user_uuid=user_uuid,
@@ -140,6 +143,7 @@ class AsyncBalancesResource(BaseBalancesResource):
             utc_endtime=utc_endtime,
             labels=labels,
             account_types=account_types,
+            page=page,
         )
 
 
@@ -153,6 +157,7 @@ class SyncBalancesResource(BaseBalancesResource):
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[BalanceRecord]:
         return self._client.run(
             self._get(
@@ -162,5 +167,6 @@ class SyncBalancesResource(BaseBalancesResource):
                 utc_endtime=utc_endtime,
                 labels=labels,
                 account_types=account_types,
+                page=page,
             )
         )
